@@ -3,8 +3,10 @@ from collections import defaultdict
 from urllib.parse import urlparse
 
 import click
+import requests
 from pycognito import Cognito
 
+from .auth import NNDAuth
 from .vars import COGNITO_NETLOC_MAPPING, CREDSTORE_PATH, DEFAULT_PROFILE
 
 
@@ -24,11 +26,13 @@ class URL(click.ParamType):
                 self.fail(
                     f"invalid URL {value}, must have a domain name", param, ctx,
                 )
-        return parsed.netloc
+        return parsed
 
 
-@click.command(
-    name="login", help="Stores login credentials for use by the Nom Nom Data CLI",
+@click.group(
+    name="login",
+    help="Stores login credentials for use by the Nom Nom Data CLI",
+    invoke_without_command=True,
 )
 @click.option(
     "--profile", envvar="NND_PROFILE", default=DEFAULT_PROFILE, show_default=True
@@ -40,9 +44,11 @@ class URL(click.ParamType):
     show_default=True,
     type=URL(),
 )
-@click.option("--username", prompt="NND Username")
-@click.option("--password", prompt=True, hide_input=True)
+@click.option("--username", default="shughes-nn")
+@click.option("--password", default="_67TY9V4rMb7egVPWaJn", hide_input=True)
 def login(profile, nomitall_url, username, password):
+    base_url = nomitall_url.netloc
+
     if not CREDSTORE_PATH.exists():
         CREDSTORE_PATH.parent.mkdir(parents=True, exist_ok=True)
         creds = defaultdict(dict)
@@ -50,8 +56,8 @@ def login(profile, nomitall_url, username, password):
         with CREDSTORE_PATH.open() as f:
             creds = defaultdict(dict, json.load(f))
     user = Cognito(
-        COGNITO_NETLOC_MAPPING[nomitall_url]["userpool-id"],
-        COGNITO_NETLOC_MAPPING[nomitall_url]["client-id"],
+        COGNITO_NETLOC_MAPPING[base_url]["userpool-id"],
+        COGNITO_NETLOC_MAPPING[base_url]["client-id"],
         username=username,
         access_key="dummy_not_used",
         secret_key="dummy_not_used",
@@ -65,12 +71,31 @@ def login(profile, nomitall_url, username, password):
         raise click.ClickException(f"Authorization failed {username}")
     except user.client.exceptions.PasswordResetRequiredException:
         raise click.ClickException(f"Password reset required for {username}")
-    creds[profile][nomitall_url] = {
+    creds[profile][base_url] = {
         "access-token": user.access_token,
         "refresh-token": user.refresh_token,
         "id-token": user.id_token,
     }
-    with CREDSTORE_PATH.open("w") as f:
-        json.dump(creds, f, indent=4)
-        CREDSTORE_PATH.chmod(0o600)
-    click.secho(f"Logged in successfully, credentials stored @ {CREDSTORE_PATH}")
+
+    session = requests.Session()
+    session.auth = NNDAuth(profile=profile)
+    user_uuid = user.verify_token(user.id_token, "id_token", "id")["sub"]
+    results = session.get(f"{nomitall_url.geturl()}/api/1/user/{user_uuid}/organizations")
+    if results.status_code == 200:
+        orgs = results.json()["results"]
+        choice_dict = {i: org for i, org in enumerate(orgs)}
+        click.secho("Available organizations:")
+        for i, org in choice_dict.items():
+            click.secho(f"{i}) {org['name']}")
+        choices = click.Choice(choice_dict.keys())
+        org_choice = click.prompt(
+            "Choose default organization", value_proc=int, type=choices, default=0
+        )
+        creds[profile][base_url]["default-org"] = choice_dict[org_choice]["uuid"]
+        with CREDSTORE_PATH.open("w") as f:
+            json.dump(creds, f, indent=4)
+            CREDSTORE_PATH.chmod(0o600)
+        click.secho(f"Logged in successfully, credentials stored @ {CREDSTORE_PATH}")
+
+    else:
+        raise click.Abort("Error fetching organizations for user")
